@@ -19,6 +19,7 @@
 #define SIGNAL_VIEW_H
 
 #include "config.h"
+#include "libkwavegui_export.h"
 
 #include <QtGlobal>
 #include <QLabel>
@@ -47,7 +48,7 @@ namespace Kwave
 
     class SignalManager; // forward declaration
 
-    class Q_DECL_EXPORT SignalView: public QWidget
+    class LIBKWAVEGUI_EXPORT SignalView: public QWidget
     {
         Q_OBJECT
     public:
@@ -81,7 +82,7 @@ namespace Kwave
                    int track = -1);
 
         /** Destructor */
-        virtual ~SignalView() Q_DECL_OVERRIDE;
+        ~SignalView() override;
 
         /**
          * refresh the content of the view.
@@ -174,19 +175,19 @@ namespace Kwave
         virtual QSharedPointer<Kwave::ViewItem> findItem(const QPoint &pos);
 
         /** slot for mouse moves, used for selection and drag&drop */
-        virtual void mouseMoveEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        void mouseMoveEvent(QMouseEvent *e) override;
 
         /** slot for mouse press, used for selection and drag&drop */
-        virtual void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        void mousePressEvent(QMouseEvent *e) override;
 
         /** slot for mouse release, used for selection and drag&drop */
-        virtual void mouseReleaseEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
+        void mouseReleaseEvent(QMouseEvent *e) override;
 
         /** slot when the mouse leaves the widget */
-        virtual void leaveEvent(QEvent *e) Q_DECL_OVERRIDE;
+        void leaveEvent(QEvent *e) override;
 
         /** handles key press events (e.g. the Escape key) */
-        virtual void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
+        void keyPressEvent(QKeyEvent *e) override;
 
         /**
          * tolerance in pixel for snapping to a label or selection border
@@ -276,16 +277,16 @@ namespace Kwave
     protected:
 
         /** @see Qt XDND documentation */
-        virtual void dragEnterEvent(QDragEnterEvent *event) Q_DECL_OVERRIDE;
+        void dragEnterEvent(QDragEnterEvent *event) override;
 
         /** @see Qt XDND documentation */
-        virtual void dragLeaveEvent(QDragLeaveEvent *event) Q_DECL_OVERRIDE;
+        void dragLeaveEvent(QDragLeaveEvent *event) override;
 
         /** @see Qt XDND documentation */
-        virtual void dropEvent(QDropEvent *event) Q_DECL_OVERRIDE;
+        void dropEvent(QDropEvent *event) override;
 
         /** @see Qt XDND documentation */
-        virtual void dragMoveEvent(QDragMoveEvent *event) Q_DECL_OVERRIDE;
+        void dragMoveEvent(QDragMoveEvent *event) override;
 
     protected:
 
@@ -359,7 +360,7 @@ namespace Kwave
             explicit PositionWidget(QWidget *parent);
 
             /** Destructor */
-            virtual ~PositionWidget() Q_DECL_OVERRIDE;
+            ~PositionWidget() override;
 
             /**
              * set a new label text and alignment
@@ -373,7 +374,7 @@ namespace Kwave
         protected:
 
             /** paint event: draws the text and the arrow */
-            virtual void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+            void paintEvent(QPaintEvent *) override;
 
             /**
              * re-creates the mask and the polygon when
