@@ -65,7 +65,7 @@ QStringList *Kwave::SelectRangePlugin::setup(QStringList &previous_params)
         new(std::nothrow) Kwave::SelectRangeDialog(parentWidget(),
             m_start_mode, m_range_mode, m_range, rate, offset, length);
     Q_ASSERT(dialog);
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
@@ -85,11 +85,11 @@ QStringList *Kwave::SelectRangePlugin::setup(QStringList &previous_params)
         );
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 }
 
@@ -191,3 +191,5 @@ int Kwave::SelectRangePlugin::interpreteParameters(QStringList &params)
 #include "SelectRangePlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_SelectRangePlugin.cpp"
